==> igniteui-react-charts-16.4.1.tgz: package/ES2015/CategoryHighlightLayer_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { AnnotationLayer } from "./AnnotationLayer";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { CategoryHighlightLayerFrame } from "./CategoryHighlightLayerFrame";
import { Type, Base, Number_$type, typeCast, fromEnum, Point_$type, markType, runOn } from "igniteui-react-core/ES2015/type";
import { XamDataChart } from "./XamDataChart";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { CategoryHighlightFrameRect } from "./CategoryHighlightFrameRect";
import { Pool$1 } from "igniteui-react-core/ES2015/Pool$1";
import { Rectangle } from "igniteui-react-core/ES2015/Rectangle";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { isNaN_, truncate } from "igniteui-react-core/ES2015/number";
import { AnnotationLayerView } from "./AnnotationLayerView";
import { BrushUtil } from "igniteui-react-core/ES2015/BrushUtil";
import { Color } from "igniteui-react-core/ES2015/Color";
export class CategoryHighlightLayer extends AnnotationLayer {
    constructor() {
        super();
        let a = new CategoryHighlightLayerFrame();
        let b = new CategoryHighlightLayerFrame();
        let c = new CategoryHighlightLayerFrame();
        let d = this.fe / 1000;
        this.lt = a;
        this.ls = b;
        this.lu = c;
        this.ab = CategoryHighlightLayer.$;
    }
    bf() {
        return new CategoryHighlightLayerView(this);
    }
    il(a) {
        super.il(a);
        this.mu = a;
    }
    get mx() {
        return this.c(CategoryHighlightLayer.m4);
    }
    set mx(a) {
        this.h(CategoryHighlightLayer.m4, a);
    }
    l9(a, b) {
        if (this.mt == null || this.mt == a) {
            if (!this.aq.c) {
                this.i4(b);
            }
        }
    }
    mv(a) {
        return a != null && a.cd();
    }
    mc(a, b) {
        super.mc(a, b);
        let c = a;
        c.g.clear();
        let d = this.mw;
        if (isNaN_(this.mq.x) && isNaN_(this.mq.y)) {
            return;
        }
        if (this.mt != null) {
            if (this.mv(this.mt)) {
                this.m2(this.mt, c, d);
            }
        }
        else {
            if (typeCast(XamDataChart.$, this.bs) !== null) {
                let e = this.bs;
                for (let f of fromEnum(e.axes)) {
                    if (typeCast(CategoryAxisBase.$, f) !== null && this.mv(f)) {
                        this.m2(f, c, d);
                    }
                }
            }
        }
    }
    m2(a, b, c) {
        if (this.bi == null || this.bi.bq.isEmpty || this.bi.bp.isEmpty) {
            return;
        }
        let d = this.mq.x;
        if (a.ce && isNaN_(d)) {
            d = 0;
        }
        d = this.bi.bp.left + this.bi.bp.width * (d - this.bi.bq.left) / this.bi.bq.width;
        let e = this.mq.y;
        if (!a.ce && isNaN_(e)) {
            e = 0;
        }
        e = this.bi.bp.top + this.bi.bp.height * (e - this.bi.bq.top) / this.bi.bq.height;
        let f = a.kn({ $type: Point_$type, x: d, y: e }, c, this.mx);
        this.m1(f, b, a);
    }
    m1(a, b, c) {
        let d = new CategoryHighlightFrameRect();
        d.b = a.left;
        d.e = a.top;
        d.c = a.right;
        d.a = a.bottom;
        d.g = this.mo();
        d.h = this.mp();
        if (d.g == null) {
            d.g = this.mu.b7(c.ib);
        }
        if (d.h == null) {
            d.h = this.mu.b7(c.ib);
        }
        d.d = this.eu;
        d.f = Base.getHashCodeStatic(c);
        if (!a.isEmpty) {
            b.g.addItem(d.f, d);
        }
    }
    mf(a, b) {
        super.mf(a, b);
        let c = this.mu.b0;
        let d = a;
        let e = 0;
        for (let f of fromEnum(d.g.values)) {
            let g = c.item(e);
            this.m3(f, g);
            e++;
        }
        c.count = e;
    }
    c6() {
        return true;
    }
    m3(a, b) {
        if (isNaN_(a.b) || isNaN_(a.e) || isNaN_(a.a) || isNaN_(a.c) || isNaN_(a.d)) {
            b._visibility = 1;
            return;
        }
        this.mu.b2(b, a.b, a.e, a.c - a.b, a.a - a.e);
        b._fill = a.g;
        b._stroke = a.h;
        b.ac = a.d;
        if (this.k2 != null) {
            b.ai = this.k2;
        }
        else {
            b.ai = null;
        }
        b.ad = this.k3;
    }
    ir(a, b, c, d) {
        super.ir(a, b, c, d);
        switch (b) {
            case CategoryHighlightLayer.$$p[0]:
                this.i4(true);
                break;
            case CategoryHighlightLayer.$$p[1]:
                this.i4(true);
                break;
        }
    }
}
CategoryHighlightLayer.m4 = DependencyProperty.i("BAndHighlightWidth", Number_$type, CategoryHighlightLayer.$, new PropertyMetadata(2, 10, (a, b) => a.raisePropertyChanged("BAndHighlightWidth", b.oldValue, b.newValue)));
CategoryHighlightLayer.$t = markType(CategoryHighlightLayer, 'CategoryHighlightLayer', AnnotationLayer.$);
Type.dep(DependencyProperty, PropertyMetadata, CategoryHighlightLayer, 'raisePropertyChanged', ['TargetAxis:mt:m5', [CategoryAxisBase.$, null], 'UseInterpolation:mw:m6', [0, false]]);
export class CategoryHighlightLayerView extends AnnotationLayerView {
    constructor(a) {
        super(a);
        this.bz = null;
        this.b0 = null;
        this.b1 = null;
        this.bz = a;
        this.b1 = new List$1(Rectangle.$, 0);
    }
    ap() {
        super.ap();
        this.b0 = ((() => {
            let $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(this, this.b8);
            $ret.activate = runOn(this, this.b3);
            $ret.disactivate = runOn(this, this.b5);
            $ret.destroy = runOn(this, this.b4);
            return $ret;
        })());
    }
    b8() {
        let a = new Rectangle();
        a.ab = false;
        this.b1.add(a);
        return a;
    }
    b3(a) {
        a._visibility = 0;
    }
    b5(a) {
        a._visibility = 1;
    }
    b4(a) {
        this.b1.remove(a);
    }
    b6(a) {
        if (a == null) {
            return a;
        }
        return BrushUtil.h(a, 0.1);
    }
    b7(a) {
        if (a != null) {
            let b = BrushUtil.h(a, 0.3);
            if (b.isGradient) {
                let c = b;
                if (c.gradientStops != null) {
                    for (let d = 0; d < c.gradientStops.length; d++) {
                        let e = c.gradientStops[d];
                        e.color = Color.u(truncate(Math.round((e.color.l) * 0.2)), e.color.o, e.color.n, e.color.m);
                        e.color = e.color;
                    }
                }
            }
            else {
                b.color = Color.u(truncate(Math.round((b.color.l) * 0.2)), b.color.o, b.color.n, b.color.m);
                b.color = b.color;
            }
            return b;
        }
        else {
            return null;
        }
    }
    b2(a, b, c, d, e) {
        a._visibility = 0;
        a.n = b;
        a.o = c;
        a.width = d;
        a.height = e;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d && !b) {
            for (let c = 0; c < this.b1.count; c++) {
                let d = this.b1._inner[c];
                if (d._visibility == 0) {
                    a.v(d);
                }
            }
        }
    }
    ai(a) {
        super.ai(a);
        for (let b = 0; b < this.b1.count; b++) {
            this.e.a2.exportRectangleData(a, this.b1._inner[b], "cihRect", ["Main", "CategoryItem"]);
        }
    }
}
CategoryHighlightLayerView.$t = markType(CategoryHighlightLayerView, 'CategoryHighlightLayerView', AnnotationLayerView.$);
/*<BeginStatics Name="Infragistics.Controls.Charts.CategoryHighlightLayer" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.CategoryHighlightLayer" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES2015/CategoryHighlightLayer_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { AnnotationLayer } from "./AnnotationLayer";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { CategoryHighlightLayerFrame } from "./CategoryHighlightLayerFrame";
import { Type, Base, Number_$type, typeCast, fromEnum, Point_$type, markType, runOn } from "igniteui-react-core/ES2015/type";
import { XamDataChart } from "./XamDataChart";
import { CategoryHighlightFrameRect } from "./CategoryHighlightFrameRect";
import { List$1 } from "igniteui-react-core/ES2015/List$1";
import { Pool$1 } from "igniteui-react-core/ES2015/Pool$1";
import { Rectangle } from "igniteui-react-core/ES2015/Rectangle";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { isNaN_, truncate } from "igniteui-react-core/ES2015/number";
import { AnnotationLayerView } from "./AnnotationLayerView";
import { BrushUtil } from "igniteui-react-core/ES2015/BrushUtil";
import { Color } from "igniteui-react-core/ES2015/Color";
export class CategoryHighlightLayer extends AnnotationLayer {
    constructor() {
        super();
        let a = new CategoryHighlightLayerFrame();
        let b = new CategoryHighlightLayerFrame();
        let c = new CategoryHighlightLayerFrame();
        let d = this.fe / 1000;
        this.lt = a;
        this.ls = b;
        this.lu = c;
        this.ab = CategoryHighlightLayer.$;
    }
    bf() {
        return new CategoryHighlightLayerView(this);
    }
    il(a) {
        super.il(a);
        this.mu = a;
    }
    get mx() {
        return this.c(CategoryHighlightLayer.m4);
    }
    set mx(a) {
        this.h(CategoryHighlightLayer.m4, a);
    }
    l9(a, b) {
        if (this.mt == null || this.mt == a) {
            if (!this.aq.c) {
                this.i4(b);
            }
        }
    }
    mv(a) {
        return a != null && a.cd();
    }
    mc(a, b) {
        super.mc(a, b);
        let c = a;
        c.g.clear();
        let d = this.mw;
        if (isNaN_(this.mq.x) && isNaN_(this.mq.y)) {
            return;
        }
        if (this.mt != null) {
            if (this.mv(this.mt)) {
                this.m2(this.mt, c, d);
            }
        }
        else {
            if (typeCast(XamDataChart.$, this.bs) !== null) {
                let e = this.bs;
                for (let f of fromEnum(e.axes)) {
                    if (typeCast(CategoryAxisBase.$, f) !== null && this.mv(f)) {
                        this.m2(f, c, d);
                    }
                }
            }
        }
    }
    m2(a, b, c) {
        if (this.bi == null || this.bi.bs.isEmpty || this.bi.br.isEmpty) {
            return;
        }
        let d = this.mq.x;
        if (a.ce && isNaN_(d)) {
            d = 0;
        }
        d = this.bi.br.left + this.bi.br.width * (d - this.bi.bs.left) / this.bi.bs.width;
        let e = this.mq.y;
        if (!a.ce && isNaN_(e)) {
            e = 0;
        }
        e = this.bi.br.top + this.bi.br.height * (e - this.bi.bs.top) / this.bi.bs.height;
        let f = a.kn({ $type: Point_$type, x: d, y: e }, c, this.mx);
        this.m1(f, b, a);
    }
    m1(a, b, c) {
        let d = new CategoryHighlightFrameRect();
        d.b = a.left;
        d.e = a.top;
        d.c = a.right;
        d.a = a.bottom;
        d.g = this.mo();
        d.h = this.mp();
        if (d.g == null) {
            d.g = this.mu.b9(c.ib);
        }
        if (d.h == null) {
            d.h = this.mu.b9(c.ib);
        }
        d.d = this.eu;
        d.f = Base.getHashCodeStatic(c);
        if (!a.isEmpty) {
            b.g.addItem(d.f, d);
        }
    }
    mf(a, b) {
        super.mf(a, b);
        let c = this.mu.b2;
        let d = a;
        let e = 0;
        for (let f of fromEnum(d.g.values)) {
            let g = c.item(e);
            this.m3(f, g);
            e++;
        }
        c.count = e;
    }
    c6() {
        return true;
    }
    m3(a, b) {
        if (isNaN_(a.b) || isNaN_(a.e) || isNaN_(a.a) || isNaN_(a.c) || isNaN_(a.d)) {
            b._visibility = 1;
            return;
        }
        this.mu.b4(b, a.b, a.e, a.c - a.b, a.a - a.e);
        b._fill = a.g;
        b._stroke = a.h;
        b.ac = a.d;
        if (this.k2 != null) {
            b.ai = this.k2;
        }
        else {
            b.ai = null;
        }
        b.ad = this.k3;
    }
    ir(a, b, c, d) {
        super.ir(a, b, c, d);
        switch (b) {
            case CategoryHighlightLayer.$$p[0]:
                this.i4(true);
                break;
            case CategoryHighlightLayer.$$p[1]:
                this.i4(true);
                break;
        }
    }
}
CategoryHighlightLayer.$t = markType(CategoryHighlightLayer, 'CategoryHighlightLayer', AnnotationLayer.$);
CategoryHighlightLayer.m4 = DependencyProperty.i("BAndHighlightWidth", Number_$type, CategoryHighlightLayer.$, new PropertyMetadata(2, 10, (a, b) => a.raisePropertyChanged("BAndHighlightWidth", b.oldValue, b.newValue)));
Type.dep(DependencyProperty, PropertyMetadata, CategoryHighlightLayer, 'raisePropertyChanged', ['TargetAxis:mt:m5', [CategoryAxisBase.$, null], 'UseInterpolation:mw:m6', [0, false]]);
export class CategoryHighlightLayerView extends AnnotationLayerView {
    constructor(a) {
        super(a);
        this.b1 = null;
        this.b2 = null;
        this.b3 = null;
        this.b1 = a;
        this.b3 = new List$1(Rectangle.$, 0);
    }
    ap() {
        super.ap();
        this.b2 = ((() => {
            let $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(this, this.ca);
            $ret.activate = runOn(this, this.b5);
            $ret.disactivate = runOn(this, this.b7);
            $ret.destroy = runOn(this, this.b6);
            return $ret;
        })());
    }
    ca() {
        let a = new Rectangle();
        a.ab = false;
        this.b3.add(a);
        return a;
    }
    b5(a) {
        a._visibility = 0;
    }
    b7(a) {
        a._visibility = 1;
    }
    b6(a) {
        this.b3.remove(a);
    }
    b8(a) {
        if (a == null) {
            return a;
        }
        return BrushUtil.h(a, 0.1);
    }
    b9(a) {
        if (a != null) {
            let b = BrushUtil.h(a, 0.3);
            if (b.isGradient) {
                let c = b;
                if (c.gradientStops != null) {
                    for (let d = 0; d < c.gradientStops.length; d++) {
                        let e = c.gradientStops[d];
                        e.color = Color.u(truncate(Math.round((e.color.l) * 0.2)), e.color.o, e.color.n, e.color.m);
                        e.color = e.color;
                    }
                }
            }
            else {
                b.color = Color.u(truncate(Math.round((b.color.l) * 0.2)), b.color.o, b.color.n, b.color.m);
                b.color = b.color;
            }
            return b;
        }
        else {
            return null;
        }
    }
    b4(a, b, c, d, e) {
        a._visibility = 0;
        a.n = b;
        a.o = c;
        a.width = d;
        a.height = e;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d && !b) {
            for (let c = 0; c < this.b3.count; c++) {
                let d = this.b3._inner[c];
                if (d._visibility == 0) {
                    a.v(d);
                }
            }
        }
    }
    ai(a) {
        super.ai(a);
        for (let b = 0; b < this.b3.count; b++) {
            this.e.a2.exportRectangleData(a, this.b3._inner[b], "cihRect", ["Main", "CategoryItem"]);
        }
    }
}
CategoryHighlightLayerView.$t = markType(CategoryHighlightLayerView, 'CategoryHighlightLayerView', AnnotationLayerView.$);
